@@ -18,17 +18,18 @@
 
 #include "oscarprotocol.h"
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <KLocalizedString>
+
 #include <kconfiggroup.h>
+#include <KSharedConfig>
 
 #include "kopeteaccountmanager.h"
 
 #include "oscaraccount.h"
 #include "connection.h"
 
-OscarProtocol::OscarProtocol( const KComponentData &instance, QObject *parent, bool canAddMyself )
-	: Kopete::Protocol( instance, parent, canAddMyself ),
+OscarProtocol::OscarProtocol( QObject *parent, bool canAddMyself )
+	: Kopete::Protocol( parent, canAddMyself ),
 	statusTitle(Kopete::Global::Properties::self()->statusTitle()),
 	statusMessage(Kopete::Global::Properties::self()->statusMessage()),
 	clientFeatures("clientFeatures", i18n("Client Features"), 0),
@@ -38,7 +39,7 @@ OscarProtocol::OscarProtocol( const KComponentData &instance, QObject *parent, b
 	client("client", i18n("Client"), QString(), 0),
 	protocolVersion("protocolVersion", i18n("Protocol Version"), QString(), 0)
 {
-	KConfigGroup config( KGlobal::config(), "OscarProtocol" );
+	KConfigGroup config( KSharedConfig::openConfig(), "OscarProtocol" );
 	if ( config.hasKey( "StartFlapSequences" ) )
 	{
 		kWarning(OSCAR_GEN_DEBUG) << "Overriding default start flap sequence algorithm!";
@@ -114,5 +115,3 @@ Kopete::Contact *OscarProtocol::deserializeContact(Kopete::MetaContact *metaCont
 	return ocontact;
 }
 
-#include "oscarprotocol.moc"
-// vim: set noet ts=4 sts=4 sw=4:
